@@ -1,9 +1,6 @@
-require File.dirname(__FILE__) + '/../lib/migration_runner'
-require 'fileutils'
-FileUtils.touch(File.join(Dir.pwd, "migration_test.db"))
-# DataMapper.setup(:default, "sqlite3://#{Dir.pwd}/migration_test.db")
-DataMapper.setup(:default, "postgres://localhost/migration_test")
-# DataMapper.setup(:default, "mysql://localhost/migration_test")
+require 'dm-migrations/migration_runner'
+
+DataMapper.setup(:default, "sqlite3::memory")
 
 DataMapper::Logger.new(STDOUT, :debug)
 DataMapper.logger.debug( "Starting Migration" )
@@ -11,9 +8,9 @@ DataMapper.logger.debug( "Starting Migration" )
 migration 1, :create_people_table do
   up do
     create_table :people do
-      column :id,     Integer, :serial => true
-      column :name,   String, :size => 50
-      column :age,    Integer
+      column :id,   Integer, :serial => true
+      column :name, String, :size => 50
+      column :age,  Integer
     end
   end
   down do
@@ -41,7 +38,7 @@ end
 # class Person
 #   include DataMapper::Resource
 #
-#   property :id, Integer, :serial => true
+#   property :id, Serial
 #   property :name, String, :size => 50
 #   property :age, Integer
 #   property :dob, DateTime, :default => Time.now
