@@ -1,11 +1,15 @@
-require 'pathname'
 require 'rubygems'
 
-gem 'rspec', '~>1.1.11'
-require 'spec'
+# use local dm-core if running from a typical dev checkout.
+lib = File.join('..', '..', 'dm-core', 'lib')
+$LOAD_PATH.unshift(lib) if File.directory?(lib)
+require 'dm-core'
 
-require Pathname(__FILE__).dirname.parent.expand_path + 'lib/dm-migrations'
-require Pathname(__FILE__).dirname.parent.expand_path + 'lib/migration_runner'
+# Support running specs with 'rake spec' and 'spec'
+$LOAD_PATH.unshift('lib') unless $LOAD_PATH.include?('lib')
+
+require 'dm-migrations'
+require 'dm-migrations/migration_runner'
 
 ADAPTERS = []
 def load_driver(name, default_uri)
@@ -20,7 +24,7 @@ def load_driver(name, default_uri)
   end
 end
 
-#ENV['ADAPTER'] ||= 'sqlite3'
+ENV['ADAPTER'] ||= 'sqlite3'
 
 load_driver(:sqlite3,  'sqlite3::memory:')
 load_driver(:mysql,    'mysql://localhost/dm_core_test')
