@@ -1,13 +1,10 @@
-require 'pathname'
-require Pathname(__FILE__).dirname + '../../spec_helper'
-
-require Pathname(__FILE__).dirname + '../../../lib/sql/table_modifier'
+require 'spec_helper'
 
 describe 'SQL module' do
   describe 'TableModifier' do
     before do
       @adapter = mock('adapter')
-      @adapter.stub!(:quote_table_name).and_return(%{'users'})
+      @adapter.stub!(:quote_name).and_return(%{'users'})
       @tc = SQL::TableModifier.new(@adapter, :users) { }
     end
 
@@ -43,7 +40,7 @@ describe 'SQL module' do
     end
 
     it 'should use the adapter to quote the table name' do
-      @adapter.should_receive(:quote_table_name).with('users').and_return(%{'users'})
+      @adapter.should_receive(:quote_name).with('users').and_return(%{'users'})
       @tc.quoted_table_name.should == %{'users'}
     end
 
